pub struct SessionCostPromptCachePrefixDrift {
pub previous_label: String,
pub current_label: String,
pub trigger: String,
pub severity: String,
pub first_changed_field: String,
pub remediation: String,
pub field_changes: Vec<SessionCostPromptCacheFieldChange>,
pub cached_input_ratio_before: Option<String>,
pub cached_input_ratio_after: Option<String>,
pub cache_creation_ratio: Option<String>,
}Fields
previous_label: Stringcurrent_label: Stringtrigger: Stringseverity: Stringfirst_changed_field: Stringremediation: StringConcrete, field-specific fix for the attributed drift cause: stabilize the changed input or move the volatile field below the cache breakpoint. Always populated so the report tells the agent what to do, not just what drifted (#pcacheremediation).
field_changes: Vec<SessionCostPromptCacheFieldChange>cached_input_ratio_before: Option<String>cached_input_ratio_after: Option<String>cache_creation_ratio: Option<String>Trait Implementations
Sourceimpl Clone for SessionCostPromptCachePrefixDrift
impl Clone for SessionCostPromptCachePrefixDrift
Sourcefn clone(&self) -> SessionCostPromptCachePrefixDrift
fn clone(&self) -> SessionCostPromptCachePrefixDrift
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for SessionCostPromptCachePrefixDrift
Sourceimpl Serialize for SessionCostPromptCachePrefixDrift
impl Serialize for SessionCostPromptCachePrefixDrift
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SessionCostPromptCachePrefixDrift